@@ -49,14 +49,14 @@ sub DEBUG     { $ENV{DEB_BUILD_PKG_JS_DEBUG} }
 sub DEBUGFILE { $ENV{DEB_BUILD_PKG_JS_DEBUG_FILE} }
 
 sub DESCRIPTION {
-    "pkg-js-tools test";
+    "dh-sequence-nodejs";
 }
 
 ### CONSTANTS
 
 # Regexp compiled from dh_nodejs/dh_root_files.excluded
 my $rootFilesIgnored =
-qr/^(?:(?:g(?:ulpfile\.(?:babel\.m?j|(?:t|m?j))|runt(?:file)?\.j)|(?:rollup[\.\-].*config|karma\.conf)\.j)s|b(?:abel\.config\.js(?:on)?|inding\.gyp|ench.*\.js|ower\.json)|c(?:o(?:mponent\.json|ntribute|pying)|hange(?:log|s?)|akefile)|a(?:ut(?:otest\.watchr|hors?)|va\.config\.js|ppveyor\.yml)|j(?:est\.config\.js|sl\.node\.conf|asmine\.json)|\.(?:mocharc\.js(?:on)?|babelrc(?:.js)?|.*)|.*\.(?:m(?:arkdown|d)|pdf|txt)|t(?:sconfig.*\.json|ests?\.js)|l(?:icen[cs]e.*|erna\.json)|(?:Docker|make)file|package-lock\.json|yarn\.lock|history)$/i;
+qr/^(?:(?:g(?:ulpfile\.(?:babel\.m?j|(?:t|m?j))|runt(?:file)?\.j)|(?:rollup[\.\-].*config|karma\.conf)\.j)s|j(?:a(?:kefile(?:\.js)?|smine\.json)|est\.config\.js|sl\.node\.conf)|b(?:abel\.config\.js(?:on)?|inding\.gyp|ench.*\.js|ower\.json)|c(?:o(?:mponent\.json|ntribute|pying)|hange(?:log|s?)|akefile)|a(?:ut(?:otest\.watchr|hors?)|va\.config\.js|ppveyor\.yml)|\.(?:babelrc(?:\.js(?:on)?)?|mocharc\.js(?:on)?|.*)|.*\.(?:m(?:arkdown|d)|pdf|txt)|t(?:sconfig.*\.json|ests?\.js)|l(?:icen[cs]e.*|erna\.json)|(?:docker|make)file|package-lock\.json|yarn\.lock|history)$/i;
 my $filesIgnored =
 qr/^(?:\.(?:(?:wafpickle-|eslint|_).*|npm(?:ignore|rc)|lock-wscript|gitignore)|.*\.(?:c(?:offee|\+\+|cp?)?|orig|def|mk|h)|(?:[jm]|binding.M)akefile|readme(?:\.(?:txt|md))?|tsconfig\.tsbuildinfo|package-lock\.json|npm-debug\.log|yarn\.lock)$/i;
 
@@ -96,7 +96,7 @@ sub pattern {
         }
         $s
     } @dirs;
-    my $pat = "^$p/" . join( '.*(?<=/)', @dirs ) . '$';
+    my $pat = "^$p/" . join( '.*(?<=/)', @dirs ) . '(?:/.*)?$';
     print "Line $tmp becomes: $pat\n";
     eval { $pattern = qr/$pat/ };
     error << "EOF" if ($@);
@@ -212,6 +212,7 @@ sub resolve_command {
     return @commands;
 }
 
+# Symlinks methods
 sub dolink {
     my ( $self, $src, $dest ) = @_;
     return if $src eq $dest;
