@@ -233,7 +233,7 @@ sub ln {
     my $module = pop;
     die "Missing module arg" unless $module;
     my $path = nodepath($module);
-    $module = "\@types/$module" if $WANTTS and $path =~ m#(\@types/.*)?/?$#;
+    $module = "\@types/$module" if $WANTTS and $path =~ m#(\@types/.*)/?$#;
     unless ($path) {
         print STDERR "$module not found in nodejs directories\n";
         return;
@@ -246,12 +246,13 @@ sub ln {
     $rpath =~ s#/$##;
     spawn( exec => [ 'mkdir', '-p', $rpath ], wait_child => 1 );
     $rpath = "node_modules/$module";
-    my $res = symlink $path, $rpath;
 
-    if ( $res == 0 ) {
-        return undef;
+    if ( -e $rpath ) {
+        print STDERR "$module exists\n";
+        return -1;
     }
-    return 1;
+    my $res = symlink $path, $rpath;
+    return $res;
 }
 
 sub link_build_modules {
@@ -389,6 +390,8 @@ sub _extLinks {
     my @dirs       = ( sort keys %$components );
     return
       unless ( @dirs
+        or -e 'debian/nodejs/extlinks'
+        or -e 'debian/nodejs/extcopies'
         or -e 'debian/nodejs/' . main_package() . '/extlinks'
         or -e 'debian/nodejs/' . main_package() . '/extcopies'
         or -d 'debian/build_modules' && main_package() eq '.' );
